% This script plots Figure 6a, 6b, 6c, 6d, 7, 8a, 8b.


% ------------- FIGURE 6a ----------------

disp('===================== FIGURE 6a =====================')

fig6a = figure(61);
figure(61), hold on, box on

switch mode
    case 'fast'
        
        load('Output6a.mat') 
        
    case 'simulateall'

    select_model6a{1} = 'M+T';
    Knots6a = {0:26/(2^4):26};
    load('noise.mat')
    Output6a = SimulateAndFitIndirect(select_model6a,Knots6a,{'C'},SFP,noise);
    
end

disp('Editing the figure.')

plot(Output6a.true_rate_ode_tmeas,Output6a.true_rate_ode(1,:),'o','LineWidth',1,'MarkerSize',6,'Color',1/255*[125 46 141]) % measured S
plot(Output6a.true_rate_ode_tmeas,Output6a.true_rate_ode(2,:),'o','LineWidth',0.5,'MarkerSize',6,'Color',1/255*[125 46 141],'MarkerFaceColor',1/255*[255 153 200]) % measured P
plot(Output6a.Lib_models_selected.tmeas,Output6a.Lib_models_selected.ode(1,:),'-','LineWidth',2,'Color',1/255*[20 43 140]) % library S
plot(Output6a.Lib_models_selected.tmeas,Output6a.Lib_models_selected.ode(2,:),'k-','LineWidth',2) % library P
plot(Output6a.SCS_models(1).tmeas,Output6a.SCS_models(1).ode(1,:),'--','LineWidth',2,'Color',1/255*[77 190 238]) % SCS S
plot(Output6a.SCS_models(1).tmeas,Output6a.SCS_models(1).ode(2,:),'--','LineWidth',2,'Color',1/255*[128 128 128]) % SCS P
xlabel('time [h]')
ylabel('concentratios [mg/L]')
set(gca,'Xlim',[0 4],'Ylim',[-.5 25.5],'FontSize',18)
legend({'measured S','measured P',[Output6a.Lib_models_selected.name ' S'],[Output6a.Lib_models_selected.name ' P'],'SCS2 S','SCS2 P'},'Position',[0.62,0.4,0.3,0.3])
legend('boxoff')

set(fig6a,'name','Figure 6a','numbertitle','off')


disp('---Finished---')


% ------------- FIGURE 6b ----------------

disp('===================== FIGURE 6b =====================')

fig6b = figure(62);
figure(62), hold on, box on

disp('Editing the figure.')

PlotResiduals(Output6a.true_rate_ode_tmeas,Output6a.true_rate_ode,Output6a.Lib_models_selected.ode,Output6a.SCS_models(1).ode,SFP.sigmaY);
legend({Output6a.Lib_models_selected.name,'SCS2','+\sigma','-\sigma'},'Position',[0.8,0.48,0.15,0.15])

set(fig6b,'name','Figure 6b','numbertitle','off')

disp('---Finished---')

% ------------- FIGURE 6c ----------------

disp('===================== FIGURE 6c =====================')

fig6c = figure(63);
figure(63), hold on, box on

switch mode
    case 'fast'
        
        load('Output6c.mat') 
        
    case 'simulateall'

    select_model6c{1} = 'Steele';
    Knots6c = {0:26/(2^4):26};
    load('noise.mat')
    Output6c = SimulateAndFitIndirect(select_model6c,Knots6c,{'C'},SFP,noise);
    
end

disp('Editing the figure.')

plot(Output6c.true_rate_ode_tmeas,Output6c.true_rate_ode(1,:),'o','LineWidth',1,'MarkerSize',6,'Color',1/255*[125 46 141]) % measured S
plot(Output6c.true_rate_ode_tmeas,Output6c.true_rate_ode(2,:),'o','LineWidth',0.5,'MarkerSize',6,'Color',1/255*[125 46 141],'MarkerFaceColor',1/255*[255 153 200]) % measured P
plot(Output6c.Lib_models_selected.tmeas,Output6c.Lib_models_selected.ode(1,:),'-','LineWidth',2,'Color',1/255*[20 43 140]) % library S
plot(Output6c.Lib_models_selected.tmeas,Output6c.Lib_models_selected.ode(2,:),'k-','LineWidth',2) % library P
plot(Output6c.SCS_models(1).tmeas,Output6c.SCS_models(1).ode(1,:),'--','LineWidth',2,'Color',1/255*[77 190 238]) % SCS S
plot(Output6c.SCS_models(1).tmeas,Output6c.SCS_models(1).ode(2,:),'--','LineWidth',2,'Color',1/255*[128 128 128]) % SCS P
xlabel('time [h]')
ylabel('concentratios [mg/L]')
set(gca,'Xlim',[0 4],'Ylim',[-.5 25.5],'FontSize',18)
legend({'measured S','measured P',[Output6c.Lib_models_selected.name ' S'],[Output6c.Lib_models_selected.name ' P'],'SCS2 S','SCS2 P'},'Position',[0.62,0.4,0.3,0.3])
legend('boxoff')

set(fig6c,'name','Figure 6c','numbertitle','off')

disp('---Finished---')

% ------------- FIGURE 6d ----------------

disp('===================== FIGURE 6d =====================')

fig6d = figure(64);
figure(64), hold on, box on

disp('Editing the figure.')

PlotResiduals(Output6c.true_rate_ode_tmeas,Output6c.true_rate_ode,Output6c.Lib_models_selected.ode,Output6c.SCS_models(1).ode,SFP.sigmaY);
legend({Output6c.Lib_models_selected.name,'SCS2','+\sigma','-\sigma'},'Position',[0.8,0.48,0.15,0.15])

set(fig6d,'name','Figure 6d','numbertitle','off')

disp('---Finished---')



% ------------- FIGURE 7 ----------------

disp('===================== FIGURE 7 =====================')

fig7 = figure(7);
figure(7), hold on, box on

select_model7 = {'Monod','Tessier','Tanh','M+T','Root','Haldane','Steele','Peeters & Eilers'};
%select_model7 = {'Monod','Tessier','Tanh','M+T','Root'};

switch mode
    case 'fast'
        
        load('WRMSR.mat') 
        
    case 'simulateall'

    Knots7 = {0:26/(2^4):26, 0:26/(2^4):26};
    shapes = {'C','N'};
    load('noise.mat')
    [Output7,WRMSR] = SimulateAndFitIndirect(select_model7,Knots7,shapes,SFP,noise);

end

PlotWRMSR(WRMSR,select_model7,fig7);

set(fig7,'name','Figure 7','numbertitle','off')

disp('---Finished---')


% ------------- FIGURE 8a ----------------

disp('===================== FIGURE 8a =====================')

fig8a = figure(81);
figure(81), hold on, box on

switch mode
    case 'fast'
        
        load('Output8.mat') 
        
    case 'simulateall'

    select_model8 = {'Steele'};
    Knots8 = {0:26/(2^4):26, 0:26/(2^4):26};
    shapes = {'C','N'};
    load('noise.mat')
    Output8 = SimulateAndFitIndirect(select_model8,Knots8,shapes,SFP,noise);
    
    
        [WRMSR(iter,nLib+k),ChatSCS] = EvaluateODE(tmeas,SFP.S0,modelSCSselected,Cmeas,[],SFP,'SCS') ;
        
end

plot(Output8.true_rate_ode_tmeas,Output8.true_rate_ode(1,:),'o','LineWidth',1,'MarkerSize',6,'Color',1/255*[125 46 141]) % measured S
plot(Output8.true_rate_ode_tmeas,Output8.true_rate_ode(2,:),'o','LineWidth',0.5,'MarkerSize',6,'Color',1/255*[125 46 141],'MarkerFaceColor',1/255*[255 153 200]) % measured P
plot(Output8.Lib_models_selected.tmeas,Output8.Lib_models_selected.ode(1,:),'-','LineWidth',2,'Color',1/255*[20 43 140]) % library S
plot(Output8.Lib_models_selected.tmeas,Output8.Lib_models_selected.ode(2,:),'k-','LineWidth',2) % library P
plot(Output8.SCS_models(1).tmeas,Output8.SCS_models(1).ode(1,:),'--','LineWidth',2,'Color',1/255*[77 190 238]) % SCS S
plot(Output8.SCS_models(1).tmeas,Output8.SCS_models(1).ode(2,:),'--','LineWidth',2,'Color',1/255*[128 128 128]) % SCS P
plot(Output8.SCS_models(2).tmeas,Output8.SCS_models(2).ode(1,:),':','LineWidth',2,'Color',1/255*[204 0 102]) % SCS S
plot(Output8.SCS_models(2).tmeas,Output8.SCS_models(2).ode(2,:),':','LineWidth',2,'Color',1/255*[187 105 88]) % SCS P
xlabel('time [h]')
ylabel('concentratios [mg/L]')
set(gca,'Xlim',[0 4],'Ylim',[-.5 25.5],'FontSize',18)
legend({'measured S','measured P',[Output8.Lib_models_selected.name ' S'],[Output8.Lib_models_selected.name ' P'],'SCS2 S','SCS2 P','SCS3 S','SCS3 P'},'Position',[0.62,0.4,0.3,0.3])
legend('boxoff')


set(fig8a,'name','Figure 8a','numbertitle','off')

disp('---Finished---')

% ------------- FIGURE 8b ----------------

disp('===================== FIGURE 8b =====================')

fig8b = figure(82);
figure(82), hold on, box on

plot(Output8.true_rate_SS,Output8.true_rate_rate,'LineWidth',7,'Color',1/255*[215 187 192])
plot(Output8.true_rate_SS,Output8.Lib_models(2).rate(Output8.true_rate_SS,Output8.Lib_models(2).pars),'k--','LineWidth',2)
plot(Output8.true_rate_SS,Output8.SCS_models(1).rate,':k','LineWidth',2)
plot(Output8.true_rate_SS,Output8.SCS_models(2).rate,':r','LineWidth',2)

disp('Editing the figure.')

axis([0, 25, 0, 11])
legend('true rate','Tessier','SCS2','SCS3')
set(gca,'FontSize',20,'XTick',0:5:25)
xlabel('substrate concentration S [mg N/L]')
ylabel('growth rate r(S) [1/day]')

set(fig8b,'name','Figure 8b','numbertitle','off')

disp('---Finished---')
